@@ -4,7 +4,7 @@ use std::time::Instant;
 fn main() {
   let start = Instant::now();
 
-  let display_infos = get_display_infos().unwrap();
+  let display_infos = get_display_infos();
   for display_info in display_infos {
     println!(
       "DisplayInfo:{} x: {} y: {} width: {} height: {} scale: {} rotation: {}\n",
