@@ -68,20 +68,16 @@ pub fn get_display_infos() -> Vec<DisplayInfo> {
 }
 
 pub fn get_display_info_from_point(x: i32, y: i32) -> Option<DisplayInfo> {
-  match get_display_infos() {
-    Ok(display_infos) => {
-      for display_info in display_infos {
-        if x >= display_info.x
-          && x <= display_info.x + display_info.width as i32
-          && y >= display_info.y
-          && y <= display_info.y + display_info.height as i32
-        {
-          return Some(display_info);
-        }
-      }
+  let display_infos = get_display_infos();
+  let display_info = display_infos.iter().find(|&&display_info| {
+    x >= display_info.x
+      && x <= display_info.x + display_info.width as i32
+      && y >= display_info.y
+      && y <= display_info.y + display_info.height as i32
+  });
 
-      None
-    }
-    Err(_) => None,
+  match display_info {
+    Some(display_info) => Some(*display_info),
+    None => None,
   }
 }
