@@ -50,16 +50,17 @@ fn get_display_rotation(sz_device: *const u16) -> f32 {
     dev_modew.dmSize = mem::size_of::<DEVMODEW>() as u16;
     let dev_modew_ptr = <*mut _>::cast(&mut dev_modew);
 
-    match EnumDisplaySettingsExW(PCWSTR(sz_device), ENUM_CURRENT_SETTINGS, dev_modew_ptr, 0) {
-      BOOL(0) => 0.0,
-      _ => {
-        return match dev_modew.Anonymous1.Anonymous2.dmDisplayOrientation {
-          1 => 90.0,
-          2 => 180.0,
-          3 => 270.0,
-          _ => 0.0,
-        };
-      }
+    let dm_display_orientation =
+      match EnumDisplaySettingsExW(PCWSTR(sz_device), ENUM_CURRENT_SETTINGS, dev_modew_ptr, 0) {
+        BOOL(0) => None,
+        _ => Some(dev_modew.Anonymous1.Anonymous2.dmDisplayOrientation),
+      };
+
+    match dm_display_orientation {
+      Some(1) => 90.0,
+      Some(2) => 180.0,
+      Some(3) => 270.0,
+      _ => 0.0,
     }
   }
 }
@@ -82,7 +83,7 @@ fn create_display_info(monitor_info_exw: MONITORINFOEXW) -> DisplayInfo {
   }
 }
 
-pub fn get_display_infos() -> Result<Vec<DisplayInfo>, i32> {
+pub fn get_display_infos() -> Vec<DisplayInfo> {
   unsafe {
     let h_monitors = Box::into_raw(Box::new(Vec::<MONITORINFOEXW>::new()));
     match EnumDisplayMonitors(
@@ -91,31 +92,31 @@ pub fn get_display_infos() -> Result<Vec<DisplayInfo>, i32> {
       Some(monitor_enum_proc),
       LPARAM(h_monitors as isize),
     ) {
-      BOOL(0) => Err(-1),
+      BOOL(0) => vec![],
       _ => {
         let display_infos = Box::from_raw(h_monitors)
           .iter()
           .map(|monitor_info_exw| create_display_info(*monitor_info_exw))
           .collect();
 
-        Ok(display_infos)
+        display_infos
       }
     }
   }
 }
 
-pub fn get_display_info_from_point(x: i32, y: i32) -> Result<DisplayInfo, i32> {
+pub fn get_display_info_from_point(x: i32, y: i32) -> Option<DisplayInfo> {
   let point = POINT { x, y };
   unsafe {
     let h_monitor = MonitorFromPoint(point, MONITOR_DEFAULTTONULL);
 
     if h_monitor.is_invalid() {
-      return Err(-1);
+      return None;
     }
 
     match get_monitor_info_exw(h_monitor) {
-      Some(monitor_info_exw) => Ok(create_display_info(monitor_info_exw)),
-      None => Err(-1),
+      Some(monitor_info_exw) => Some(create_display_info(monitor_info_exw)),
+      None => None,
     }
   }
 }
